==> un-applet_1.4_all.tar.bz2: un-applet_1.4_all/usr/share/un-applet/un-applet.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
###############################################################################
# un-applet
# copyright (c) 2015-2016 Michael Lange <klappnase@tuxfamily.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the #hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################

import libmisc
libmisc.install_gettext()

import ConfigHandler
ConfigHandler.initialize()

import getopt
import os
import sys
import time
import Tkinter
import ttk
from tkMessageBox import showerror

import applet

def usage():
    print('un-applet (c) 2015-2016 Michael Lange <klappnase@tuxfamily.org>\n' +\
          'Usage: un-applet                 : start the update notifier applet\n' +\
          '       un-applet -h , --help     : print this message and exit')

try:
    opts, files = getopt.getopt(sys.argv[1:], 'h', ['help'])
except getopt.GetoptError:
    usage()
    sys.exit(1)
for opt, val in opts:
    if opt in ('-h', '--help'):
        usage()
        sys.exit(0)

# timeout for older versions of the IceWm system tray
startup_delay = ConfigHandler.get('STARTUP_DELAY')
if startup_delay:
    time.sleep(startup_delay)

root = libmisc.mainwindow()

applet = applet.UpdateNotifierApplet(root)

def close(*args):
    applet.close()
root.quit_command(close)

root.update_idletasks()
root.mainloop()
root.destroy()

# messages to be displayed on the terminal emulator during the upgrade
# or update of the package database,
# these are only here so that they appear in the .pot file
term_msgs = (_('Running command:'),
             _('Updating the list of pending updates...'),
             _('Error while trying to access mirror server(s).'),
             _('Failed to update package database.'),
             _('Upgrade finished'),
             _('Please press Enter to close the window.'),
             _('Testing mirror server(s)...'),
             _('Failed to update package database.'),
             _('Checking if the package database is locked by another process...'),
             _('yes.'),
             _('Could not get lock:'),
             _('no.'),
             _('Updating package database...'),
             _('Update of package database complete.'),
             _('updated package(s) available.'),
             _('Installing updates...'),
             _('Error'),
             _('Update finished'),
             _('You configured un-applet to use aptitude to install available updates'),
             _('however aptitude does not seem to be installed on your system.'),
             _('1. use apt-get instead of aptitude to install the available updates now.'),
             _('2. do nothing and install the available updates later.'),
             _('Please enter your choice'),
             _('Update cancelled'),
             _('Software update has been cancelled.'),
             _('Invalid input'),
             _('Generating the list of available updates...'),
             _('Starting update of the package database...'),
             _('ok'),
             _('error'),
             _('mirror server(s) could not be reached.')
             )

==> un-applet_1.5_all.tar.bz2: un-applet_1.5_all/usr/share/un-applet/un-applet.py <==
#!/usr/bin/python2
# -*- coding: utf-8 -*-
###############################################################################
# un-applet
# copyright (c) 2015-2017 Michael Lange <klappnase@tuxfamily.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the #hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
###############################################################################

import libmisc
libmisc.install_gettext()

import ConfigHandler
ConfigHandler.initialize()

import getopt
import os
import sys
import time
import applet

def usage():
    print('un-applet (c) 2015-2017 Michael Lange <klappnase@tuxfamily.org>\n' +\
          'Usage: un-applet                 : start the update notifier applet\n' +\
          '       un-applet -h , --help     : print this message and exit')

try:
    opts, files = getopt.getopt(sys.argv[1:], 'h', ['help'])
except getopt.GetoptError:
    usage()
    sys.exit(1)
for opt, val in opts:
    if opt in ('-h', '--help'):
        usage()
        sys.exit(0)

# timeout for older versions of the IceWm system tray
startup_delay = ConfigHandler.get('STARTUP_DELAY')
if startup_delay:
    time.sleep(startup_delay)

root = libmisc.mainwindow()

applet = applet.UpdateNotifierApplet(root)

def close(*args):
    applet.close()
root.quit_command(close)

root.update_idletasks()
root.mainloop()
root.destroy()

# messages to be displayed on the terminal emulator during the upgrade
# or update of the package database,
# these are only here so that they appear in the .pot file
term_msgs = (_('Running command:'),
             _('Updating the list of pending updates...'),
             _('Error while trying to access mirror server(s).'),
             _('Failed to update package database.'),
             _('Upgrade finished'),
             _('Please press Enter to close the window.'),
             _('Testing mirror server(s)...'),
             _('Failed to update package database.'),
             _('Checking if the package database is locked by another process...'),
             _('yes.'),
             _('Could not get lock:'),
             _('no.'),
             _('Updating package database...'),
             _('Update of package database complete.'),
             _('updated package(s) available.'),
             _('Installing updates...'),
             _('Error'),
             _('Update finished'),
             _('You configured un-applet to use aptitude to install available updates'),
             _('however aptitude does not seem to be installed on your system.'),
             _('1. use apt-get instead of aptitude to install the available updates now.'),
             _('2. do nothing and install the available updates later.'),
             _('Please enter your choice'),
             _('Update cancelled'),
             _('Software update has been cancelled.'),
             _('Invalid input'),
             _('Generating the list of available updates...'),
             _('Starting update of the package database...'),
             _('ok'),
             _('error'),
             _('mirror server(s) could not be reached.'),
             _('Software upgrade successfully finished.'),
             _('Software upgrade finished with error(s).')
             )
